==> newland-toubiz-poi-neos-1.2.0-956943.zip: Classes/Service/ArticleUrlService.php <==
<?php
namespace Newland\Toubiz\Poi\Neos\Service;

use Neos\ContentRepository\Domain\Model\Node;
use Neos\Eel\FlowQuery\FlowQuery;
use Neos\Flow\Annotations as Flow;
use Neos\Flow\Mvc\Controller\ControllerContext;
use Neos\Neos\Service\LinkingService;
use Newland\Toubiz\Sync\Neos\Domain\Model\Article;

/**
 * @Flow\Scope("singleton")
 */
class ArticleUrlService
{

    /**
     * @var Node[]
     */
    private $nodeCache = [];

    /**
     * @Flow\InjectConfiguration(package="Newland.Toubiz.Poi.Neos.lodging.targetUri")
     * @var string
     */
    protected $lodgingUri;

    /**
     * @Flow\Inject
     * @var LinkingService
     */
    protected $linkingService;

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return mixed|null|string
     * @throws \Neos\Eel\Exception
     * @throws \Neos\Neos\Exception
     */
    public function generateUrl(Article $article, ControllerContext $context)
    {
        $url = $this->generateNodeBasedUrl($article, $context);
        if (!$url && $article->getIsLodging()) {
            $url = $this->generateLodgingUrl($article);
        }
        return $url;
    }

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return null|string
     * @throws \Neos\Eel\Exception
     * @throws \Neos\Neos\Exception
     */
    public function generateNodeBasedUrl(Article $article, ControllerContext $context)
    {
        $node = $this->nodeForArticleFromControllerContext($article, $context);
        if (!$node) {
            return null;
        }

        return $this->linkingService->createNodeUri(
            $context,
            $node,
            null,
            null,
            false,
            [
                '--newland_toubiz_poi_neos-list' => [
                    '@package' => 'newland.toubiz.poi.neos',
                    '@controller' => 'pointofinterests',
                    '@action' => 'show',
                    'article' => $article
                ]
            ]
        );
    }

    /**
     * @param Article $article
     * @return mixed|null
     */
    public function generateLodgingUrl(Article $article)
    {
        if (!$this->lodgingUri) {
            return null;
        }

        return str_replace(':id', $article->getOriginalId(), $this->lodgingUri);
    }

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return Node|null
     * @throws \Neos\Eel\Exception
     */
    public function nodeForArticleFromControllerContext(Article $article, ControllerContext $context)
    {
        return $this->nodeForArticle(
            $article,
            $context
                ->getRequest()
                ->getInternalArgument('__node')
                ->getContext()
                ->getCurrentSiteNode()
        );
    }

    /**
     * @param Article $article
     * @param Node $site
     * @return null|Node
     * @throws \Neos\Eel\Exception
     */
    public function nodeForArticle(Article $article, Node $site)
    {
        $key = $site->getPath() . $article->getMainType();
        if (!array_key_exists($key, $this->nodeCache)) {
            $this->nodeCache[$key] = (new FlowQuery([ $site ]))
                ->find('[instanceof Newland.Toubiz.Poi.Neos:List][articleType *= "' . $article->getMainType() . '"]')
                ->parents('[instanceof Neos.NodeTypes:Page]')
                ->get(0);
        }
        return $this->nodeCache[$key];
    }

}

==> newland-toubiz-poi-neos-1.3.0-856726.zip: Classes/Service/ArticleUrlService.php <==
<?php
namespace Newland\Toubiz\Poi\Neos\Service;

/*
 * This file is part of the "toubiz-poi-neos" package.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

use Neos\ContentRepository\Domain\Model\Node;
use Neos\Eel\FlowQuery\FlowQuery;
use Neos\Flow\Annotations as Flow;
use Neos\Flow\Mvc\Controller\ControllerContext;
use Neos\Neos\Service\LinkingService;
use Newland\Toubiz\Sync\Neos\Domain\Model\Article;

/**
 * @Flow\Scope("singleton")
 */
class ArticleUrlService
{
    /**
     * @var Node[]
     */
    private $nodeCache = [];

    /**
     * @Flow\InjectConfiguration(package="Newland.Toubiz.Poi.Neos.lodging.targetUri")
     * @var string
     * @deprecated since 1.3.0, superseeded by $lodgingBaseUri
     */
    protected $lodgingUri;

    /**
     * @Flow\InjectConfiguration(package="Newland.Toubiz.Poi.Neos.lodging.targetBaseUri")
     * @var string
     */
    protected $lodgingBaseUri;

    /**
     * @Flow\Inject
     * @var LinkingService
     */
    protected $linkingService;

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return mixed|null|string
     * @throws \Neos\Eel\Exception
     * @throws \Neos\Neos\Exception
     */
    public function generateUrl(Article $article, ControllerContext $context)
    {
        $url = $this->generateNodeBasedUrl($article, $context);
        if (!$url && $article->getIsLodging()) {
            $url = $this->generateLodgingUrl($article);
        }
        return $url;
    }

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return null|string
     * @throws \Neos\Eel\Exception
     * @throws \Neos\Neos\Exception
     */
    public function generateNodeBasedUrl(Article $article, ControllerContext $context)
    {
        $node = $this->nodeForArticleFromControllerContext($article, $context);
        if (!$node) {
            return null;
        }

        return $this->linkingService->createNodeUri(
            $context,
            $node,
            null,
            null,
            false,
            [
                '--newland_toubiz_poi_neos-list' => [
                    '@package' => 'newland.toubiz.poi.neos',
                    '@controller' => 'pointofinterests',
                    '@action' => 'show',
                    'article' => $article
                ]
            ]
        );
    }

    /**
     * @param Article $article
     * @return string|null
     */
    public function generateLodgingUrl(Article $article)
    {
        if ($this->lodgingUri) {
            return str_replace(':id', $article->getOriginalId(), $this->lodgingUri);
        }

        if ($this->lodgingBaseUri) {
            return $this->lodgingBaseUri . $article->getDetailUri(); 
        }
    }

    /**
     * @param Article $article
     * @param ControllerContext $context
     * @return Node|null
     * @throws \Neos\Eel\Exception
     */
    public function nodeForArticleFromControllerContext(Article $article, ControllerContext $context)
    {
        return $this->nodeForArticle(
            $article,
            $context
                ->getRequest()
                ->getInternalArgument('__node')
                ->getContext()
                ->getCurrentSiteNode()
        );
    }

    /**
     * @param Article $article
     * @param Node $site
     * @return null|Node
     * @throws \Neos\Eel\Exception
     */
    public function nodeForArticle(Article $article, Node $site)
    {
        $key = $site->getPath() . $article->getMainType();
        if (!array_key_exists($key, $this->nodeCache)) {
            $this->nodeCache[$key] = (new FlowQuery([ $site ]))
                ->find('[instanceof Newland.Toubiz.Poi.Neos:List][articleType *= "' . $article->getMainType() . '"]')
                ->parents('[instanceof Neos.NodeTypes:Page]')
                ->get(0);
        }
        return $this->nodeCache[$key];
    }

}
